@@ -4,7 +4,7 @@ from .validate import Validate
 # Metadata
 __doc__ = "Package to help with normalizing data needed for the platform!"
 # Github CI/CD greps for the version number.
-__version__ = "1.3.3"
-__author__ = "Michiel Masselink"
-__email__ = "m.masselink@yahoo.com"
+__version__ = "1.3.4"
+__author__ = "Realstats"
+__email__ = "info@realstats.com"
 __license__ = "MIT"
